﻿using System;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace News;

public partial class NewsContext : DbContext
{
    public NewsContext()
    {
    }

    public NewsContext(DbContextOptions<NewsContext> options)
        : base(options)
    {
    }

    public virtual DbSet<Author> Authors { get; set; }

    public virtual DbSet<Category> Categories { get; set; }

    public virtual DbSet<Comment> Comments { get; set; }

    public virtual DbSet<News> News { get; set; }

    public virtual DbSet<User> Users { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
#warning To protect potentially sensitive information in your connection string, you should move it out of source code. You can avoid scaffolding the connection string by using the Name= syntax to read it from configuration - see https://go.microsoft.com/fwlink/?linkid=2131148. For more guidance on storing connection strings, see http://go.microsoft.com/fwlink/?LinkId=723263.
        => optionsBuilder.UseNpgsql("Host=192.168.56.103;Port=5432;Database=news;Username=postgres;Password=54050");

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Author>(entity =>
        {
            entity.HasKey(e => e.AuthorId).HasName("author_pkey");

            entity.ToTable("author", tb => tb.HasComment("авторы"));

            entity.Property(e => e.AuthorId)
                .HasDefaultValueSql("nextval('author_id_seq'::regclass)")
                .HasColumnName("author_id");
            entity.Property(e => e.AuthorName)
                .HasMaxLength(150)
                .HasColumnName("author_name");
        });

        modelBuilder.Entity<Category>(entity =>
        {
            entity.HasKey(e => e.CategoryId).HasName("category_pkey");

            entity.ToTable("category", tb => tb.HasComment("категории"));

            entity.Property(e => e.CategoryId)
                .HasDefaultValueSql("nextval('category_id_seq'::regclass)")
                .HasComment("ид категории")
                .HasColumnName("category_id");
            entity.Property(e => e.CategoryName)
                .HasMaxLength(150)
                .HasComment("наименование")
                .HasColumnName("category_name");
        });

        modelBuilder.Entity<Comment>(entity =>
        {
            entity.HasKey(e => new { e.UserId, e.NewsId }).HasName("comment_pkey");

            entity.ToTable("comment", tb => tb.HasComment("комментарии"));

            entity.Property(e => e.UserId).HasColumnName("user_id");
            entity.Property(e => e.NewsId).HasColumnName("news_id");
            entity.Property(e => e.CommentText)
                .HasMaxLength(2000)
                .HasColumnName("comment_text");

            entity.HasOne(d => d.News).WithMany(p => p.Comments)
                .HasForeignKey(d => d.NewsId)
                .HasConstraintName("news_id");

            entity.HasOne(d => d.User).WithMany(p => p.Comments)
                .HasForeignKey(d => d.UserId)
                .HasConstraintName("user_id");
        });

        modelBuilder.Entity<News>(entity =>
        {
            entity.HasKey(e => e.NewsId).HasName("news_pkey");

            entity.ToTable("news", tb => tb.HasComment("новости"));

            entity.Property(e => e.NewsId)
                .HasDefaultValueSql("nextval('news_id_seq'::regclass)")
                .HasColumnName("news_id");
            entity.Property(e => e.AuthorId).HasColumnName("author_id");
            entity.Property(e => e.CategoryId).HasColumnName("category_id");
            entity.Property(e => e.NewsDate).HasColumnName("news_date");
            entity.Property(e => e.NewsName)
                .HasMaxLength(200)
                .HasColumnName("news_name");

            entity.HasOne(d => d.Author).WithMany(p => p.News)
                .HasForeignKey(d => d.AuthorId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("author_id");

            entity.HasOne(d => d.Category).WithMany(p => p.News)
                .HasForeignKey(d => d.CategoryId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("category_id");
        });

        modelBuilder.Entity<User>(entity =>
        {
            entity.HasKey(e => e.UserId).HasName("user_pkey");

            entity.ToTable("user", tb => tb.HasComment("пользователи"));

            entity.Property(e => e.UserId)
                .HasDefaultValueSql("nextval('user_id_seq'::regclass)")
                .HasColumnName("user_id");
            entity.Property(e => e.UserName)
                .HasMaxLength(150)
                .HasColumnName("user_name");
        });
        modelBuilder.HasSequence("author_id_seq");
        modelBuilder.HasSequence("category_id_seq");
        modelBuilder.HasSequence("comment_id_seq");
        modelBuilder.HasSequence("news_id_seq");
        modelBuilder.HasSequence("user_id_seq");

        OnModelCreatingPartial(modelBuilder);
    }

    partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
}
